@@ -50,13 +50,12 @@ impl<R: Read> Read for StripHeaderReader<R> {
 }
 
 impl<R: Read> StripHeaderReader<R> {
-
     fn strip_head_read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
         let mut backing = vec![0; buf.len()];
-        let mut local_buf : &mut [u8] = &mut *backing;
+        let mut local_buf: &mut [u8] = &mut *backing;
 
         loop {
-            let read = try!(self.r.read(local_buf));
+            let read = self.r.read(local_buf)?;
             if read == 0 {
                 return Ok(0);
             }
@@ -70,7 +69,7 @@ impl<R: Read> StripHeaderReader<R> {
                             self.header_state = HeaderState::PastHeader;
                             return Ok(read);
                         }
-                    },
+                    }
                     HeaderState::Junk => {
                         if byte == b'\r' {
                             HeaderState::AwaitingNewline
@@ -79,15 +78,14 @@ impl<R: Read> StripHeaderReader<R> {
                         } else {
                             HeaderState::Junk
                         }
-                    },
+                    }
                     HeaderState::AwaitingNewline => {
                         if byte == b'\n' {
                             HeaderState::PastHeader
                         } else {
-                            fail!(io::Error::new(io::ErrorKind::InvalidData,
-                                                 "expected newline"));
+                            fail!(io::Error::new(io::ErrorKind::InvalidData, "expected newline"));
                         }
-                    },
+                    }
                     HeaderState::PastHeader => {
                         let rem = read - offset;
                         (&mut buf[..rem]).copy_from_slice(&local_buf[offset..read]);
@@ -107,8 +105,7 @@ pub fn strip_junk_header(slice: &[u8]) -> io::Result<&[u8]> {
     let mut need_newline = false;
     for (idx, &byte) in slice.iter().enumerate() {
         if need_newline && byte != b'\n' {
-            fail!(io::Error::new(io::ErrorKind::InvalidData,
-                                 "expected newline"));
+            fail!(io::Error::new(io::ErrorKind::InvalidData, "expected newline"));
         } else if is_junk_json(byte) {
             continue;
         } else if byte == b'\r' {
@@ -141,7 +138,7 @@ fn decode_regular(rsm: RawSourceMap) -> Result<SourceMap> {
                 continue;
             }
 
-            let nums = try!(parse_vlq_segment(segment));
+            let nums = parse_vlq_segment(segment)?;
             dst_col = (dst_col as i64 + nums[0]) as u32;
 
             let mut src = !0;
@@ -183,33 +180,36 @@ fn decode_regular(rsm: RawSourceMap) -> Result<SourceMap> {
     if let Some(source_root) = rsm.source_root {
         if !source_root.is_empty() {
             let source_root = source_root.trim_right_matches('/');
-            sources = sources.into_iter().map(|x| {
-                if x.len() > 0 && (x.starts_with('/') ||
-                                   x.starts_with("http:") ||
-                                   x.starts_with("https:")) {
-                    x
-                } else {
-                    format!("{}/{}", source_root, x)
-                }
-            }).collect();
+            sources = sources.into_iter()
+                .map(|x| {
+                    if x.len() > 0 &&
+                       (x.starts_with('/') || x.starts_with("http:") || x.starts_with("https:")) {
+                        x
+                    } else {
+                        format!("{}/{}", source_root, x)
+                    }
+                })
+                .collect();
         }
     }
 
     // apparently we can encounter some non string types in real world
     // sourcemaps :(
-    let names = names.into_iter().map(|val| {
-        match val {
-            Value::String(s) => s,
-            Value::U64(i) => format!("{}", i),
-            _ => "".into(),
-        }
-    }).collect::<Vec<String>>();
+    let names = names.into_iter()
+        .map(|val| {
+            match val {
+                Value::String(s) => s,
+                Value::U64(i) => format!("{}", i),
+                _ => "".into(),
+            }
+        })
+        .collect::<Vec<String>>();
 
     // file sometimes is not a string for unexplicable reasons
     let file = rsm.file.map(|val| {
         match val {
             Value::String(s) => s,
-            _ => "<invalid>".into()
+            _ => "<invalid>".into(),
         }
     });
 
@@ -220,14 +220,12 @@ fn decode_index(rsm: RawSourceMap) -> Result<SourceMapIndex> {
     let mut sections = vec![];
 
     for mut raw_section in rsm.sections.unwrap_or(vec![]) {
-        sections.push(SourceMapSection::new(
-            (raw_section.offset.line, raw_section.offset.column),
-            raw_section.url,
-            match raw_section.map.take() {
-                Some(map) => Some(try!(decode_regular(*map))),
-                None => None,
-            }
-        ));
+        sections.push(SourceMapSection::new((raw_section.offset.line, raw_section.offset.column),
+                                            raw_section.url,
+                                            match raw_section.map.take() {
+                                                Some(map) => Some(decode_regular(*map)?),
+                                                None => None,
+                                            }));
     }
 
     sections.sort_by_key(|sect| sect.get_offset());
@@ -236,7 +234,7 @@ fn decode_index(rsm: RawSourceMap) -> Result<SourceMapIndex> {
     let file = rsm.file.map(|val| {
         match val {
             Value::String(s) => s,
-            _ => "<invalid>".into()
+            _ => "<invalid>".into(),
         }
     });
 
@@ -245,9 +243,9 @@ fn decode_index(rsm: RawSourceMap) -> Result<SourceMapIndex> {
 
 fn decode_common(rsm: RawSourceMap) -> Result<DecodedMap> {
     Ok(if rsm.sections.is_some() {
-        DecodedMap::Index(try!(decode_index(rsm)))
+        DecodedMap::Index(decode_index(rsm)?)
     } else {
-        DecodedMap::Regular(try!(decode_regular(rsm)))
+        DecodedMap::Regular(decode_regular(rsm)?)
     })
 }
 
@@ -258,7 +256,7 @@ fn decode_common(rsm: RawSourceMap) -> Result<DecodedMap> {
 pub fn decode<R: Read>(rdr: R) -> Result<DecodedMap> {
     let mut rdr = StripHeaderReader::new(rdr);
     let mut rdr = BufReader::new(&mut rdr);
-    let rsm : RawSourceMap = try!(serde_json::from_reader(&mut rdr));
+    let rsm: RawSourceMap = serde_json::from_reader(&mut rdr)?;
     decode_common(rsm)
 }
 
@@ -267,8 +265,8 @@ pub fn decode<R: Read>(rdr: R) -> Result<DecodedMap> {
 /// This supports both sourcemaps and sourcemap indexes unless the
 /// specialized methods on the individual types.
 pub fn decode_slice(slice: &[u8]) -> Result<DecodedMap> {
-    let content = try!(strip_junk_header(slice));
-    let rsm : RawSourceMap = try!(serde_json::from_slice(content));
+    let content = strip_junk_header(slice)?;
+    let rsm: RawSourceMap = serde_json::from_slice(content)?;
     decode_common(rsm)
 }
 
@@ -278,6 +276,6 @@ pub fn decode_data_url(url: &str) -> Result<DecodedMap> {
         fail!(Error::InvalidDataUrl);
     }
     let data_b64 = &url.as_bytes()[DATA_PREABLE.len()..];
-    let data = try!(base64::u8de(data_b64).map_err(|_| Error::InvalidDataUrl));
+    let data = base64::u8de(data_b64).map_err(|_| Error::InvalidDataUrl)?;
     decode_slice(&data[..])
 }
