@@ -3,14 +3,14 @@
 //! ## Installation
 //!
 //! The crate is called sourcemap and you can depend on it via cargo:
-//! 
+//!
 //! ```toml
 //! [dependencies]
 //! sourcemap = "*"
 //! ```
 //!
 //! If you want to use the git version:
-//! 
+//!
 //! ```toml
 //! [dependencies.sourcemap]
 //! git = "https://github.com/mitsuhiko/rust-sourcemap.git"
@@ -50,14 +50,12 @@ extern crate url;
 
 mod macros;
 
-pub use types::{RawToken, Token, TokenIter, SourceMap, SourceMapIndex,
-                SourceMapSection, SourceMapSectionIter, RewriteOptions,
-                DecodedMap};
+pub use types::{RawToken, Token, TokenIter, SourceMap, SourceMapIndex, SourceMapSection,
+                SourceMapSectionIter, RewriteOptions, DecodedMap};
 pub use builder::SourceMapBuilder;
 pub use errors::{Result, Error};
 pub use decoder::{decode, decode_slice, decode_data_url};
-pub use detector::{SourceMapRef, locate_sourcemap_reference,
-                   locate_sourcemap_reference_slice,
+pub use detector::{SourceMapRef, locate_sourcemap_reference, locate_sourcemap_reference_slice,
                    is_sourcemap, is_sourcemap_slice};
 
 mod builder;
